@@ -172,12 +172,6 @@ def main():
     global root_folder, expected_error_count, recursive, error_count
     total_error_count = 0
 
-    # Generalize root folder path
-    if not root_folder.endswith("**"):
-        if not root_folder.endswith("/") and not root_folder.endswith("\\"):
-            root_folder = root_folder + "\\"
-        root_folder = root_folder + "**"
-
     files = glob.glob(root_folder + "/**.xml", recursive=recursive)
 
     # remove files and folders to ignore
